# llms.txt <!-- omit in toc -->

This module allows site administrators to input and manage the contents of an `llms.txt` file through a simple admin settings form. The configured content is then dynamically displayed at the `/llms.txt` route, making it easy to update and serve the file without needing direct file system access.

For a full description of the module, visit the
[project page](https://www.drupal.org/project/llmstxt).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/llmstxt).

You can also add contents to the `llms.txt` file by implementing
hook_llmstxt(). See `llmstxt.api.php` for more information.


## Table of contents

- [Requirements](#requirements)
- [Installation](#installation)
- [Configuration](#configuration)
- [Frequently asked questions](#frequently-asked-questions)
- [Special thanks](#special-thanks)
- [Maintainers](#maintainers)


## Requirements

No additional modules or libraries are required.


## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

Once you have the llms.txt module installed, make sure to delete or rename
the `llms.txt` file you might already have in the root of your Drupal 
installation. Otherwise, the module cannot receive requests for the
/llms.txt path, your webserver will serve the static file first.


## Configuration

Configure the llms.txt content in Administration » Configuration »
Search and metadata » llms.txt


## Frequently asked questions

**Q: Can this module work if I have clean URLs disabled?**

**A:** Yes it can! In the .htaccess file of your Drupal's root directory, add
   the following line to the mod_rewrite section, immediately after the line
   that says "RewriteEngine on":

```.htaccess
RewriteRule ^(llms.txt)$ index.php?q=$1
```

**Q: Does this module work together with Drupal Core "Fast 404 pages" feature?**

**A:** Yes, but you need to add llms.txt to the 'exclude_paths' of your
   settings.php.

Default Drupal Fast404 configuration (in settings.php):

```php
$config['system.performance']['fast_404']['exclude_paths'] =
   '/\/(?:styles)|(?:system\/files)\//';
```

New Drupal Fast404 configuration (in settings.php) to allow llms.txt module:

```php
$config['system.performance']['fast_404']['exclude_paths'] =
  '/\/(?:styles)|(?:system\/files)\/|(?:llms.txt)/';
```

**Q: How can I install the module with custom default llms.txt?**

**A:** The module _upon install only_ allows adding a default.llms.txt to the
defaults folder.

   1. Save your custom llms.txt to "/sites/default/default.llms.txt"
   2. Run the module installation.


## Special thanks

This module is a fork of [RobotsTxt](https://www.drupal.org/project/robotstxt) project. Credit and appreciation go to its maintainers for their original work.

## Maintainers

- Nodar Davituri - [davituri](https://www.drupal.org/u/davituri)
- Giorgi Gagoshidze - [ggagosh](https://www.drupal.org/u/ggagosh)
- Giorgi Jibladze - [jibla](https://www.drupal.org/u/jibla)

The work is sponsored by:

- [Omedia](https://drupal.org/omedia) - Digital agency with 18 years of experience delivering high-impact web solutions with a focus on performance, accessibility, and open-source. Visit [omedia.dev](https://omedia.dev) to learn more.
