<?php

namespace Drupal\llmstxt\Form;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Configure llms.txt settings for this site.
 */
class LlmsTxtSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'llmstxt_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['llmstxt.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('llmstxt.settings');

    $form['llmstxt_content'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Contents of llms.txt'),
      '#description' => $this->t('See <a href="https://llmstxt.org/" target="_blank">llmstxt.org</a> for more information on how to compose your <a href=":llmstxt" target="_blank">llms.txt</a> file.', [':llmstxt' => Url::fromUri('base://llms.txt')->toString()]),
      '#default_value' => $config->get('content'),
      '#cols' => 60,
      '#rows' => 10,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('llmstxt.settings');
    $config
      ->set('content', $form_state->getValue('llmstxt_content'))
      ->save();

    Cache::invalidateTags(['llmstxt']);
    parent::submitForm($form, $form_state);
  }

}
